elephant.test.test_kcsd module — Elephant 0.5.0 documentation

# elephant.test.test_kcsd module

Unit tests for the kCSD methods

This was written by : Chaitanya Chintaluri, Laboratory of Neuroinformatics, Nencki Institute of Exprimental Biology, Warsaw.

license: | Modified BSD, see LICENSE.txt for details.

class `elephant.test.test_kcsd.` `KCSD1D_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_kcsd1d_estimate`(cv_params={})
  `test_valid_inputs`()

class `elephant.test.test_kcsd.` `KCSD2D_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_kcsd2d_estimate`(cv_params={})
  `test_moi_estimate`()
  `test_valid_inputs`()

class `elephant.test.test_kcsd.` `KCSD3D_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_kcsd3d_estimate`(cv_params={})
  `test_valid_inputs`()